@@ -8,6 +8,8 @@ pub enum Error<R, P> {
     Request(R),
     /// Any [`Provider`](crate::Provider)-specific error, e.g. failing to parse the response from the API.
     Provider(P), // TODO: Journey not found, ...
+    /// Provider doesn't have implementation for this specific feature
+    NotImplemented,
 }
 
 impl<R: Display, P: Display> Display for Error<R, P> {
@@ -15,6 +17,7 @@ impl<R: Display, P: Display> Display for Error<R, P> {
         match self {
             Self::Request(e) => write!(f, "error requesting data: {}", e),
             Self::Provider(e) => write!(f, "provider specific error: {}", e),
+            Self::NotImplemented => write!(f, "not implemented by this provider"),
         }
     }
 }
